@@ -13,6 +13,7 @@
 #'@param OBSERVATION The array of resource observations from the observation model, used to estimate abundance of resources
 #'@param model The type of model being applied (Currently only individual-based
 #' -- i.e., 'agent-based' -- models are allowed)
+#'@param ... Other arguments to be passed to a user-defined model
 #'@return The manager function outputs an R list that includes five separate arrays, including (1) an new RESOURCES array, (2) a new AGENTS array, (3) a new LAND array, (4) a new ACTIONS array, and a new (5) COST array, each of which might be affected by the user function. The new arrays can then be read back into the broader GMSE function, thereby affecting the input into the user, resource, and observation models.
 #'@examples
 #'\dontrun{
@@ -31,7 +32,7 @@ manager <- function(RESOURCES   = NULL,
                     inter_tabl  = NULL,
                     OBSERVATION = NULL,
                     model       = "IBM"
-) {
+                   ) {
     check_model <- 0;
     if(model == "IBM"){
         # Relevant warnings below if the inputs are not of the right type
@@ -62,6 +63,15 @@ manager <- function(RESOURCES   = NULL,
         if(!is.array(OBSERVATION)){
             stop("Warning: Observation needs to be in an array");
         }
+        if(dim(RESOURCES)[2] != 20){
+            stop("The RESOURCES array has the wrong number of columns");
+        }
+        if(dim(LAND)[3] != 3){
+            stop("The landscape doesn't have enough layers");
+        }
+        if(dim(AGENTS)[2] != 17){
+            stop("The agent array has the wrong number of columns");
+        }
         # If all checks out, then run the manager model
         MANAGER_OUT <- run_manage(RESOURCE_c    = RESOURCES,
                                   LANDSCAPE_c   = LAND,
@@ -73,12 +83,12 @@ manager <- function(RESOURCES   = NULL,
                                   INTERACT_c    = inter_tabl,
                                   OBSERVATION_c = OBSERVATION
         );
-   
         check_model <- 1;
     }
     if(check_model == 0){
         stop("Invalid model selected (Must be 'IBM')");
     }
+    names(MANAGER_OUT) <- c("RESOURCES", "AGENTS", "LAND", "ACTION", "COST");
     return(MANAGER_OUT);
 }
 
