@@ -259,15 +259,16 @@ void res_to_counts(double ***population, int **interact_table, double *paras,
                    int row, int agent){
     
     int i, interest_row, int_num;
-    double foc_effect;
+    double foc_effect, lambda;
     
     int_num = (int) paras[60];
+    lambda  = paras[105];
     
     foc_effect  = 0.0;
     foc_effect -= population[row][7][agent];  /* Times birth account for repr?*/
-    foc_effect -= population[row][8][agent];  /* But only remove E offspring? */
-    foc_effect -= population[row][9][agent];  /* But also remove E offspring? */
-    foc_effect += population[row][10][agent]; /* But should less mortality    */
+    foc_effect -= population[row][8][agent] * (1 + lambda);
+    foc_effect -= population[row][9][agent] * lambda;
+    foc_effect += population[row][10][agent] * lambda;
     foc_effect += population[row][11][agent]; /* But should affect offspring? */
     interest_row = 0;
     while(interest_row < int_num){
